df(1)

df - summarize free disk space

Showing IRIX 6.5.15. Unchanged since IRIX 6.5.

     NAME
          df - summarize free disk space

     SYNOPSIS
          df [-aikPv] [-t fstype] [-x fstype] [--all] [--inodes]
          [--type=fstype] [--exclude-type=fstype] [--kilobytes]
          [--portability] [--print-type] [--help] [--version]
          [filename...]

     DESCRIPTION
          This documentation is no longer being maintained and may be
          inaccurate or incomplete.  The Texinfo documentation is now
          the authoritative source.

          This manual page documents the GNU version of df.  df
          displays the amount of disk space available on the
          filesystem containing each file name argument.  If no file
          name is given, the space available on all currently mounted
          filesystems is shown.  Disk space is shown in 1K blocks by
          default, unless the environment variable POSIXLY_CORRECT is
          set, in which case 512-byte blocks are used.

          If an argument is the absolute file name of a disk device
          node containing a mounted filesystem, df shows the space
          available on that filesystem rather than on the filesystem
          containing the device node (which is always the root
          filesystem).  This version of df cannot show the space
          available on unmounted filesystems, because on most kinds of
          systems doing so requires very nonportable intimate
          knowledge of filesystem structures.

        OPTIONS
          -a, --all
               Include in the listing filesystems that have 0 blocks,
               which are omitted by default.  Such filesystems are
               typically special-purpose pseudo-filesystems, such as
               automounter entries.  On some systems, filesystems of
               type ``ignore'' or ``auto'' are also omitted by default
               and included in the listing by this option.

          -i, --inodes
               List inode usage information instead of block usage.
               An inode (short for ``index node'') is a special kind
               of disk block that contains information about a file,
               such as its owner, permissions, timestamps, and
               location on the disk.

          -k, --kilobytes
               Print sizes in 1K blocks instead of 512-byte blocks.
               This overrides the environment variable
               POSIXLY_CORRECT.
          -P, --portability
               Use the POSIX output format.  This is like the default
               format except that the information about each
               filesystem is always printed on exactly one line; a
               mount device is never put on a line by itself.  This
               means that if the mount device name is more than 20
               characters long (as for some network mounts), the
               columns are misaligned.

          -T, --print-type
               Print a type string for each filesystem.  Any such
               printed filesystem type name may be used as an argument
               to either of the --type= or --exclude-type= options.

          -t, --type=fstype
               Limit the listing to filesystems of type fstype.
               Multiple filesystem types can be shown by giving
               multiple -t options.  By default, all filesystem types
               are listed.

          -x, --exclude-type=fstype
               Limit the listing to filesystems not of type fstype.
               Multiple filesystem types can be eliminated by giving
               multiple -x options.  By default, all filesystem types
               are listed.

          -v   Ignored; for compatibility with System V versions of
               df.

          --help
               Print a usage message on standard output and exit
               successfully.

          --version
               Print version information on standard output then exit
               successfully.